##  REST APIs
SAP LeanIX REST APIs offer a versatile interface for interacting with a wide range of resources, including the meta model, workspace settings, users, metrics, surveys, and more. These APIs are designed for seamless integration with systems that support RESTful interactions.
To enhance your experience with SAP LeanIX REST APIs, we provide the [OpenAPI explorer![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F "https://app.leanix.net/openapi-explorer/"). This tool enables you to explore APIs, send requests, and view responses directly in your browser. To navigate to the OpenAPI explorer from your workspace, on the help menu, choose Developer Tools > OpenAPI Documentation.
For additional information, see [REST APIs](https://help.sap.com/docs/leanix/ea/rest-apis?locale=en-US&state=PRODUCTION&version=CLOUD "Get started with SAP LeanIX REST APIs.").
